import { Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { SERVER_API_URL } from 'app/app.constants';
import { createRequestOption } from 'app/shared';
import { ICustomerContact } from 'app/shared/model/customer-contact.model';

type EntityResponseType = HttpResponse<ICustomerContact>;
type EntityArrayResponseType = HttpResponse<ICustomerContact[]>;

@Injectable({ providedIn: 'root' })
export class CustomerContactService {
    public resourceUrl = SERVER_API_URL + 'api/customer-contacts';

    constructor(protected http: HttpClient) {}

    create(customerContact: ICustomerContact): Observable<EntityResponseType> {
        return this.http.post<ICustomerContact>(this.resourceUrl, customerContact, { observe: 'response' });
    }

    update(customerContact: ICustomerContact): Observable<EntityResponseType> {
        return this.http.put<ICustomerContact>(this.resourceUrl, customerContact, { observe: 'response' });
    }

    find(id: number): Observable<EntityResponseType> {
        return this.http.get<ICustomerContact>(`${this.resourceUrl}/${id}`, { observe: 'response' });
    }

    query(req?: any): Observable<EntityArrayResponseType> {
        const options = createRequestOption(req);
        return this.http.get<ICustomerContact[]>(this.resourceUrl, { params: options, observe: 'response' });
    }

    delete(id: number): Observable<HttpResponse<any>> {
        return this.http.delete<any>(`${this.resourceUrl}/${id}`, { observe: 'response' });
    }
}
